@@ -1,18 +1,28 @@
 from abc import ABC, abstractmethod
 from collections.abc import Mapping
+import pandas as pd
+from mikeio import eum
 
 from ..comparison import BaseComparer
 
 
+def _parse_itemInfo(itemInfo):
+    if itemInfo is None:
+        return eum.ItemInfo(eum.EUMType.Undefined)
+    if isinstance(itemInfo, eum.ItemInfo):
+        return itemInfo
+    return eum.ItemInfo(itemInfo)
+
+
 class ModelResultInterface(ABC):  # pragma: no cover
     @property
     @abstractmethod
-    def start_time(self):
+    def start_time(self) -> pd.Timestamp:
         pass
 
     @property
     @abstractmethod
-    def end_time(self):
+    def end_time(self) -> pd.Timestamp:
         pass
 
     @property
@@ -28,10 +38,16 @@ class ModelResultInterface(ABC):  # pragma: no cover
     def extract_observation(self, observation) -> BaseComparer:
         pass
 
+    def __repr__(self):
+        txt = [f"<{self.__class__.__name__}> '{self.name}'"]
+        txt.append(f"- Item: {self.item_name}")
+        return "\n".join(txt)
+
+    def _in_domain(self, x, y) -> bool:
+        return True
+
 
 class MultiItemModelResult(ABC, Mapping):  # pragma: no cover
-    _mr_items = None
-
     @property
     @abstractmethod
     def item_names(self):
@@ -62,3 +78,9 @@ class MultiItemModelResult(ABC, Mapping):  # pragma: no cover
     @abstractmethod
     def end_time(self):
         pass
+
+    def __repr__(self):
+        txt = [f"<{self.__class__.__name__}> '{self.name}'"]
+        for j, item in enumerate(self.item_names):
+            txt.append(f"- Item: {j}: {item}")
+        return "\n".join(txt)
