@@ -10,16 +10,26 @@ import os
 import numpy as np
 import pandas as pd
 from datetime import datetime
-from shapely.geometry import Point, MultiPoint
 from mikeio import Dfs0, eum
+from copy import deepcopy
 from .utils import make_unique_index
 
 
+def _parse_item(items, item, item_str="item"):
+    if isinstance(item, int):
+        item = len(items) + item if (item < 0) else item
+        if (item < 0) or (item >= len(items)):
+            raise IndexError(f"{item_str} is out of range (0, {len(items)})")
+    elif isinstance(item, str):
+        item = items.index(item)
+    else:
+        raise TypeError(f"{item_str} must be int or string")
+    return item
+
+
 class Observation:
     "Base class for all types of observations"
 
-    color = "#d62728"
-
     # DHI: darkblue: #004165,
     #      midblue:  #0098DB,
     #      gray:     #8B8D8E,
@@ -37,6 +47,10 @@ class Observation:
     def __init__(
         self, name: str = None, df=None, itemInfo=None, variable_name: str = None
     ):
+        self.color = "#d62728"
+
+        if name is None:
+            name = "Observation"
         self.name = name
         if not isinstance(df.index, pd.DatetimeIndex):
             raise TypeError(
@@ -60,14 +74,14 @@ class Observation:
         return self.df.index
 
     @property
-    def start_time(self) -> datetime:
-        """First time instance (as datetime)"""
-        return self.time[0].to_pydatetime()
+    def start_time(self) -> pd.Timestamp:
+        """First time instance (as pd.Timestamp)"""
+        return self.time[0]
 
     @property
-    def end_time(self) -> datetime:
-        """Last time instance (as datetime)"""
-        return self.time[-1].to_pydatetime()
+    def end_time(self) -> pd.Timestamp:
+        """Last time instance (as pd.Timestamp)"""
+        return self.time[-1]
 
     @property
     def values(self) -> np.ndarray:
@@ -93,31 +107,74 @@ class Observation:
             txt = f"{txt} [{unit_display_name(unit)}]"
         return txt
 
-    def hist(self, bins=100, **kwargs):
-        """plot histogram"""
-        ax = self.df.iloc[:, -1].hist(bins=bins, color=self.color, **kwargs)
-        ax.set_title(self.name)
+    def hist(self, bins=100, title=None, color=None, **kwargs):
+        """plot histogram of observation values
+
+        Wraps pandas.DataFrame hist() method.
+
+        Parameters
+        ----------
+        bins : int, optional
+            specification of bins, by default 100
+        title : str, optional
+            plot title, default: observation name
+        color : str, optional
+            plot color, by default "#d62728"
+        kwargs : other keyword arguments to df.hist()
+
+        Returns
+        -------
+        matplotlib axes
+        """
+        title = self.name if title is None else title
+        kwargs["color"] = self.color if color is None else color
+
+        ax = self.df.iloc[:, -1].hist(bins=bins, **kwargs)
+        ax.set_title(title)
         ax.set_xlabel(self._unit_text())
         return ax
 
+    def __copy__(self):
+        return deepcopy(self)
+
+    def copy(self):
+        return self.__copy__()
+
 
 class PointObservation(Observation):
     """Class for observations of fixed locations
 
-    Can be created from a dfs0 file or from a pd.DataFrame
+    Create a PointObservation from a dfs0 file or a pd.DataFrame.
+
+    Parameters
+    ----------
+    input : (str, pd.DataFrame, pd.Series)
+        dfs0 filename or dataframe with the data
+    item : (int, str), optional
+        index or name of the wanted item, by default None
+    x : float, optional
+        x-coordinate of the observation point, by default None
+    y : float, optional
+        y-coordinate of the observation point, by default None
+    z : float, optional
+        z-coordinate of the observation point, by default None
+    name : str, optional
+        user-defined name for easy identification in plots etc, by default file basename
+    variable_name : str, optional
+        user-defined variable name in case of multiple variables, by default eumType name
 
     Examples
     --------
     >>> o1 = PointObservation("klagshamn.dfs0", item=0, x=366844, y=6154291, name="Klagshamn")
+    >>> o1 = PointObservation("klagshamn.dfs0", item="Water Level", x=366844, y=6154291)
     >>> o1 = PointObservation(df, item=0, x=366844, y=6154291, name="Klagshamn")
+    >>> o1 = PointObservation(df["Water Level"], x=366844, y=6154291)
     """
 
-    x = None
-    y = None
-    z = None
-
     @property
-    def geometry(self) -> Point:
+    def geometry(self):
+        from shapely.geometry import Point
+
         """Coordinates of observation"""
         if self.z is None:
             return Point(self.x, self.y)
@@ -127,6 +184,7 @@ class PointObservation(Observation):
     def __init__(
         self,
         filename,
+        *,
         item=None,
         x: float = None,
         y: float = None,
@@ -134,32 +192,7 @@ class PointObservation(Observation):
         name: str = None,
         variable_name: str = None,
     ):
-        """Create a PointObservation from a dfs0 file or a pd.DataFrame.
 
-        Parameters
-        ----------
-        input : (str, pd.DataFrame, pd.Series)
-            dfs0 filename or dataframe with the data
-        item : (int, str), optional
-            index or name of the wanted item, by default None
-        x : float, optional
-            x-coordinate of the observation point, by default None
-        y : float, optional
-            y-coordinate of the observation point, by default None
-        z : float, optional
-            z-coordinate of the observation point, by default None
-        name : str, optional
-            user-defined name for easy identification in plots etc, by default file basename
-        variable_name : str, optional
-            user-defined variable name in case of multiple variables, by default eumType name
-
-        Examples
-        --------
-        >>> o1 = PointObservation("klagshamn.dfs0", item=0, x=366844, y=6154291, name="Klagshamn")
-        >>> o1 = PointObservation("klagshamn.dfs0", item="Water Level", x=366844, y=6154291)
-        >>> o1 = PointObservation(df, item=0, x=366844, y=6154291, name="Klagshamn")
-        >>> o1 = PointObservation(df["Water Level"], x=366844, y=6154291)
-        """
         self.x = x
         self.y = y
         self.z = z
@@ -188,6 +221,8 @@ class PointObservation(Observation):
                 df = df[[item]]
                 default_name = item
             elif isinstance(item, int):
+                if item < 0:
+                    item = len(df.columns) + item
                 default_name = df.columns[item]
                 df = df.iloc[:, item]
             else:
@@ -248,10 +283,29 @@ class PointObservation(Observation):
         df.dropna(inplace=True)
         return df, itemInfo
 
-    def plot(self, **kwargs):
-        """plot timeseries"""
-        ax = self.df.plot(marker=".", color=self.color, linestyle="None", **kwargs)
-        ax.set_title(self.name)
+    def plot(self, title=None, color=None, marker=".", linestyle="None", **kwargs):
+        """plot observation timeseries
+
+        Wraps pandas.DataFrame plot() method.
+
+        Parameters
+        ----------
+        title : str, optional
+            plot title, default: [name]
+        color : str, optional
+            plot color, by default '#d62728'
+        marker : str, optional
+            plot marker, by default '.'
+        linestyle : str, optional
+            line style, by default None
+        kwargs: other keyword arguments to df.plot()
+        """
+        kwargs["color"] = self.color if color is None else color
+        ax = self.df.plot(marker=marker, linestyle=linestyle, **kwargs)
+
+        title = self.name if title is None else title
+        ax.set_title(title)
+
         ax.set_ylabel(self._unit_text())
         return ax
 
@@ -261,10 +315,33 @@ class TrackObservation(Observation):
 
     The data needs in addition to the datetime of each single observation point also, x and y coordinates.
 
+    Create TrackObservation from dfs0 or DataFrame
+
+    Parameters
+    ----------
+    input : (str, pd.DataFrame)
+        path to dfs0 file or DataFrame with track data
+    item : (str, int), optional
+        item name or index of values, by default 2
+    name : str, optional
+        user-defined name for easy identification in plots etc, by default file basename
+    variable_name : str, optional
+        user-defined variable name in case of multiple variables, by default eumType name
+    x_item : (str, int), optional
+        item name or index of x-coordinate, by default 0
+    y_item : (str, int), optional
+        item name or index of y-coordinate, by default 1
+
     Examples
     --------
     >>> o1 = TrackObservation("track.dfs0", item=2, name="c2")
 
+    >>> o1 = TrackObservation("track.dfs0", item="wind_speed", name="c2")
+
+    >>> o1 = TrackObservation("lon_after_lat.dfs0", item="wl", x_item=1, y_item=0)
+
+    >>> o1 = TrackObservation("track_wl.dfs0", item="wl", x_item="lon", y_item="lat")
+
     >>> df = pd.DataFrame(
     ...         {
     ...             "t": pd.date_range("2010-01-01", freq="10s", periods=n),
@@ -300,7 +377,9 @@ class TrackObservation(Observation):
     """
 
     @property
-    def geometry(self) -> MultiPoint:
+    def geometry(self):
+        from shapely.geometry import MultiPoint
+
         """Coordinates of observation"""
         return MultiPoint(self.df.iloc[:, 0:2].values)
 
@@ -317,32 +396,45 @@ class TrackObservation(Observation):
         return self.df.iloc[:, 2].values
 
     def __init__(
-        self, filename, item: int = 2, name: str = None, variable_name: str = None
+        self,
+        input,
+        *,
+        item: int = None,
+        name: str = None,
+        variable_name: str = None,
+        x_item=0,
+        y_item=1,
     ):
 
         self._filename = None
         self._item = None
 
-        if isinstance(filename, pd.DataFrame):  # or isinstance(filename, pd.Series):
-            df = filename
-            df = df.iloc[:, [0, 1, item]]
+        if isinstance(input, pd.DataFrame):
+            df = input
+            df_items = df.columns.to_list()
+            items = self._parse_track_items(df_items, x_item, y_item, item)
+            df = df.iloc[:, items].copy()
             itemInfo = eum.ItemInfo(eum.EUMType.Undefined)
-        elif isinstance(filename, str):
-            assert os.path.exists(filename)
-            self._filename = filename
+        elif isinstance(input, str):
+            assert os.path.exists(input)
+            self._filename = input
             if name is None:
-                name = os.path.basename(filename).split(".")[0]
+                name = os.path.basename(input).split(".")[0]
 
-            ext = os.path.splitext(filename)[-1]
+            ext = os.path.splitext(input)[-1]
             if ext == ".dfs0":
-                items = [0, 1, item]
-                df, itemInfo = self._read_dfs0(Dfs0(filename), items)
+                dfs = Dfs0(input)
+                file_items = [i.name for i in dfs.items]
+                items = self._parse_track_items(file_items, x_item, y_item, item)
+                df, itemInfo = self._read_dfs0(dfs, items)
                 self._item = itemInfo.name
             else:
-                raise NotImplementedError()
+                raise NotImplementedError(
+                    "Only dfs0 files and DataFrames are supported"
+                )
         else:
             raise TypeError(
-                f"input must be str or pandas DataFrame! Given input has type {type(filename)}"
+                f"input must be str or pandas DataFrame! Given input has type {type(input)}"
             )
 
         if not df.index.is_unique:
@@ -352,6 +444,30 @@ class TrackObservation(Observation):
             name=name, df=df, itemInfo=itemInfo, variable_name=variable_name
         )
 
+    @staticmethod
+    def _parse_track_items(items, x_item, y_item, item):
+        """If input has exactly 3 items we accept item=None"""
+        if len(items) < 3:
+            raise ValueError(
+                f"Input has only {len(items)} items. It should have at least 3."
+            )
+        if item is None:
+            if len(items) == 3:
+                item = 2
+            elif len(items) > 3:
+                raise ValueError("Input has more than 3 items, but item was not given!")
+        else:
+            item = _parse_item(items, item)
+
+        x_item = _parse_item(items, x_item, "x_item")
+        y_item = _parse_item(items, y_item, "y_item")
+
+        if (item == x_item) or (item == y_item) or (x_item == y_item):
+            raise ValueError(
+                f"x-item ({x_item}), y-item ({y_item}) and value-item ({item}) must be different!"
+            )
+        return [x_item, y_item, item]
+
     def __repr__(self):
         out = f"TrackObservation: {self.name}, n={self.n_points}"
         return out
