@@ -1,5 +1,6 @@
 import pytest
 import numpy as np
+import matplotlib.pyplot as plt
 
 from fmskill import ModelResult
 from fmskill import PointObservation, TrackObservation
@@ -93,15 +94,18 @@ def test_mm_skill_model(cc):
     assert df.loc["EPL"].n == 67
     assert df.loc["c2"].n == 113
 
+    df2 = cc.skill(model=-2).df
+    assert df2.loc["c2"].rmse == df.loc["c2"].rmse
+
 
 def test_mm_skill_missing_model(cc):
-    with pytest.raises(ValueError):
+    with pytest.raises(KeyError):
         cc.skill(model="SW_3")
-    with pytest.raises(ValueError):
+    with pytest.raises(IndexError):
         cc.skill(model=999)
-    with pytest.raises(ValueError):
+    with pytest.raises((KeyError, IndexError)):
         cc.skill(model=[999, "SW_2"])
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
         cc.skill(model=[0.1])
 
 
@@ -110,6 +114,9 @@ def test_mm_skill_obs(cc):
     assert len(s) == 2
     assert pytest.approx(s.loc["SW_2"].bias) == 0.081431053
 
+    s2 = cc.skill(observation=-1)
+    assert s.loc["SW_2"].bias == s2.loc["SW_2"].bias
+
     df = cc.mean_skill(model=0, observation=[0, "c2"]).df
     assert pytest.approx(df.si[0]) == 0.10358979
 
@@ -121,7 +128,7 @@ def test_mm_skill_missing_obs(cc, o1):
         cc.skill(observation=999)
     with pytest.raises((KeyError, IndexError)):
         cc.skill(observation=["c2", 999])
-    with pytest.raises(KeyError):
+    with pytest.raises(TypeError):
         cc.skill(observation=[o1])
 
 
@@ -195,26 +202,67 @@ def test_mm_skill_metrics(cc):
         cc.skill(model="SW_1", metrics=["mean_se"])
     with pytest.raises(AttributeError):
         cc.skill(model="SW_1", metrics=[mtr.fake])
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
         cc.skill(model="SW_1", metrics=[47])
 
 
 def test_mm_mean_skill(cc):
     s = cc.mean_skill()
     assert len(s) == 2
-    s = cc.mean_skill(weights=[0.2, 0.3, 1.0])
-    assert len(s) == 2
-    s = cc.mean_skill(weights="points")
+    assert s.loc["SW_1"].rmse == pytest.approx(0.309118939)
+
+
+def test_mm_mean_skill_weights_list(cc):
+    s = cc.mean_skill(weights=[0.3, 0.2, 1.0])
     assert len(s) == 2
+    assert s.loc["SW_1"].rmse == pytest.approx(0.3261788143)
+
+    s = cc.mean_skill(weights=[100000000000.0, 1.0, 1.0])
+    assert s.loc["SW_1"].rmse < 1.0
+
     s = cc.mean_skill(weights=1)
     assert len(s) == 2
-    s = cc.mean_skill(weights="equal")
-    assert len(s) == 2
+    assert s.loc["SW_1"].rmse == pytest.approx(0.309118939)
+
     with pytest.raises(ValueError):
         # too many weights
         cc.mean_skill(weights=[0.2, 0.3, 0.4, 0.5])
 
 
+def test_mm_mean_skill_weights_str(cc):
+    s = cc.mean_skill(weights="points")
+    assert len(s) == 2
+    assert s.loc["SW_1"].rmse == pytest.approx(0.3367349)
+
+    s = cc.mean_skill(weights="equal")
+    assert len(s) == 2
+    assert s.loc["SW_1"].rmse == pytest.approx(0.309118939)
+
+
+def test_mm_mean_skill_weights_dict(cc):
+    s = cc.mean_skill(weights={"EPL": 0.2, "c2": 1.0, "HKNA": 0.3})
+    assert len(s) == 2
+    assert s.loc["SW_1"].rmse == pytest.approx(0.3261788143)
+
+    s2 = cc.mean_skill(weights=[0.3, 0.2, 1.0])
+    assert s.loc["SW_1"].rmse == s2.loc["SW_1"].rmse
+    assert s.loc["SW_2"].rmse == s2.loc["SW_2"].rmse
+
+    s = cc.mean_skill(weights={"EPL": 2.0})
+    assert len(s) == 2
+    assert s.loc["SW_1"].rmse == pytest.approx(0.319830126)
+
+    s2 = cc.mean_skill(weights={"EPL": 2.0, "c2": 1.0, "HKNA": 1.0})
+    assert s.loc["SW_1"].rmse == s2.loc["SW_1"].rmse
+    assert s.loc["SW_2"].rmse == s2.loc["SW_2"].rmse
+
+
+def test_mean_skill_points(cc):
+    s = cc.mean_skill_points()
+    assert len(s) == 2
+    assert s.loc["SW_1"].rmse == pytest.approx(0.33927729)
+
+
 def test_mm_scatter(cc):
     cc.scatter(model="SW_1", observation=[0, 1])
     cc.scatter(model="SW_2", show_points=False)
@@ -222,17 +270,24 @@ def test_mm_scatter(cc):
     cc.scatter(model="SW_2", binsize=0.5)
     cc.scatter(model="SW_2", nbins=5, reg_method="odr")
     cc.scatter(model="SW_2", title="t", xlabel="x", ylabel="y")
+    cc.scatter(model="SW_2", show_points=True)
+    cc.scatter(model="SW_2", show_points=100)
+    cc.scatter(model="SW_2", show_points=0.75)
+    cc.scatter(model="SW_2", show_density=True)
+    cc.scatter(model="SW_2", show_points=0.75, show_density=True)
     # cc.scatter(model="SW_2", binsize=0.5, backend="plotly")
     assert True
+    plt.close("all")
 
 
 def test_mm_taylor(cc):
     cc.taylor(model="SW_1", observation=[0, 1])
-    cc.taylor()
+    cc.taylor(normalize_std=True)
     cc.taylor(figsize=(4, 4))
     cc.taylor(model="SW_2", start="2017-10-28")
     cc[0].taylor(model=0, end="2017-10-29")
     assert True
+    plt.close("all")
 
 
 def test_mm_plot_timeseries(cc):
@@ -242,3 +297,4 @@ def test_mm_plot_timeseries(cc):
     # cc["EPL"].plot_timeseries(backend="plotly")
     with pytest.raises(ValueError):
         cc["EPL"].plot_timeseries(backend="mpl")
+    plt.close("all")
