@@ -1,9 +1,14 @@
+import pytest
 import fmskill
 from fmskill.report import Reporter
+import matplotlib as mpl
+
+mpl.use("Agg")
 
 
 def test_markdown(tmpdir):
-    connector = fmskill.from_config("tests/testdata/conf.yml", validate_eum=False)
+    with pytest.warns(UserWarning, match="Item type mismatch!"):
+        connector = fmskill.from_config("tests/testdata/conf.yml", validate_eum=False)
     reporter = Reporter(connector, tmpdir)
 
     filename = reporter.to_markdown()
@@ -13,7 +18,8 @@ def test_markdown(tmpdir):
 
 
 def test_html(tmpdir):
-    connector = fmskill.from_config("tests/testdata/conf.yml", validate_eum=False)
+    with pytest.warns(UserWarning, match="Item type mismatch!"):
+        connector = fmskill.from_config("tests/testdata/conf.yml", validate_eum=False)
     reporter = Reporter(connector, tmpdir)
 
     filename = reporter.to_html()
